# Utilities for implementation of a Connect Four game

def make_empty_grid(rows, cols, empty_ch):
    '''
    Creates a grid with the given number of rows and columns which all cells
    contain the given character 'empty_ch'
    '''
    grid = []
    for row in range(0, rows):
        row_elements = []
        for col in range(0, cols):
            row_elements.append(empty_ch)
        grid.append(row_elements)
    return grid


def make_grid_from_strings(string_list):
    '''
    Creates a grid of characters in which each string of the given
    list becomes one row.  This is not used for the game, but is 
    useful for testing.
    '''
    result = []
    for s in string_list:
        result.append(list(s))
    return result
    

def find_max_empty_row(grid, col, empty_ch):
    '''
    Returns the largest index of an empty cell that has only empty 
    cells above it within the given column. An empty cell is one that 
    contains the given character 'empty_ch'. Returns -1 if all
    cells in the column are nonempty.
    '''
    # TODO
    return -1


def check_grid(grid, ch, size):
    '''
    Returns True if the grid contains a run of the given size 
    consisting of the given character.  The run may be horizontal,
    vertical, diagonal to the right, or diagonal to the left.
    '''
    result = check_rows(grid, ch, size)
    if result:
        return True
    result = check_cols(grid, ch, size)
    if result:
        return True
    result = check_diag_right(grid, ch, size)
    if result:
        return True
    result = check_diag_left(grid, ch, size)
    if result:
        return True
    return False
  
    
def check_list(list, ch, size):
    '''
    Helper function that determines whether the given list contains a 
    run of the given size consisting of the given character.  
    '''
    if len(list) < size:
        return False
    target = ch * size
    source = "".join(list)
    return source.find(target) >= 0


def make_right_diag_list(grid, start_row, start_col):
    '''
    Returns a list of the elements in the given grid located
    diagonally below and to the right of the given row and column.
    '''
    # TODO
    return None


def make_left_diag_list(grid, start_row, start_col):
    '''
    Returns a list of the elements in the given grid located
    diagonally below and to the left of the given row and column.
    '''
    # TODO
    return None


def check_diag_right(grid, ch, size):
    '''
    Returns True if the grid contains a right diagonal run of the 
    given size consisting of the given character. 
    '''
    # TODO
    return False


def check_diag_left(grid, ch, size):
    '''
    Returns True if the grid contains a right diagonal run of the 
    given size consisting of the given character. 
    '''
    # TODO
    return False


def check_cols(grid, ch, size):
    '''
    Returns True if the grid contains a vertical run of the 
    given size consisting of the given character. 
    '''
    for col in range(0, len(grid[0])):
        list = []
        for row in range(0, len(grid)):
            list.append(grid[row][col])
        result = check_list(list, ch, size)
        if result:
            return True
    return False


def check_rows(grid, ch, size):
    '''
    Returns True if the grid contains a horizontal run of the 
    given size consisting of the given character. 
    '''
    for row in range(0, len(grid)):
        result = check_list(grid[row], ch, size)
        if result:
            return True
    return False
    
    
